# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Coretype(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Coretype - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'schema': 'Schema',
            'current': 'bool',
            'validation_fields': 'list[str]',
            'validation_limits': 'ValidationLimits',
            'item_validation_fields': 'list[str]',
            'item_validation_limits': 'ItemValidationLimits',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'version': 'version',
            'date_created': 'dateCreated',
            'schema': 'schema',
            'current': 'current',
            'validation_fields': 'validationFields',
            'validation_limits': 'validationLimits',
            'item_validation_fields': 'itemValidationFields',
            'item_validation_limits': 'itemValidationLimits',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._version = None
        self._date_created = None
        self._schema = None
        self._current = None
        self._validation_fields = None
        self._validation_limits = None
        self._item_validation_fields = None
        self._item_validation_limits = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Coretype.
        The globally unique identifier for the object.

        :return: The id of this Coretype.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Coretype.
        The globally unique identifier for the object.

        :param id: The id of this Coretype.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Coretype.


        :return: The name of this Coretype.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Coretype.


        :param name: The name of this Coretype.
        :type: str
        """
        
        self._name = name

    @property
    def version(self):
        """
        Gets the version of this Coretype.
        A positive integer denoting the core type's version

        :return: The version of this Coretype.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Coretype.
        A positive integer denoting the core type's version

        :param version: The version of this Coretype.
        :type: int
        """
        
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this Coretype.
        The date the core type was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this Coretype.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this Coretype.
        The date the core type was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this Coretype.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def schema(self):
        """
        Gets the schema of this Coretype.
        The core type's built-in schema

        :return: The schema of this Coretype.
        :rtype: Schema
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """
        Sets the schema of this Coretype.
        The core type's built-in schema

        :param schema: The schema of this Coretype.
        :type: Schema
        """
        
        self._schema = schema

    @property
    def current(self):
        """
        Gets the current of this Coretype.
        A boolean indicating if the core type's version is the current one in use by the system

        :return: The current of this Coretype.
        :rtype: bool
        """
        return self._current

    @current.setter
    def current(self, current):
        """
        Sets the current of this Coretype.
        A boolean indicating if the core type's version is the current one in use by the system

        :param current: The current of this Coretype.
        :type: bool
        """
        
        self._current = current

    @property
    def validation_fields(self):
        """
        Gets the validation_fields of this Coretype.
        An array of strings naming the fields of the core type subject to validation.  Validation constraints are specified by a schema author using the core type.

        :return: The validation_fields of this Coretype.
        :rtype: list[str]
        """
        return self._validation_fields

    @validation_fields.setter
    def validation_fields(self, validation_fields):
        """
        Sets the validation_fields of this Coretype.
        An array of strings naming the fields of the core type subject to validation.  Validation constraints are specified by a schema author using the core type.

        :param validation_fields: The validation_fields of this Coretype.
        :type: list[str]
        """
        
        self._validation_fields = validation_fields

    @property
    def validation_limits(self):
        """
        Gets the validation_limits of this Coretype.
        A structure denoting the system-imposed minimum and maximum string length (for text-based core types) or numeric values (for number-based) core types.  For example, the validationLimits for a text-based core type specify the min/max values for a minimum string length (minLength) constraint supplied by a schemaauthor on a text field.  Similarly, the maxLength's min/max specifies maximum string length constraint supplied by a schema author for the same field.

        :return: The validation_limits of this Coretype.
        :rtype: ValidationLimits
        """
        return self._validation_limits

    @validation_limits.setter
    def validation_limits(self, validation_limits):
        """
        Sets the validation_limits of this Coretype.
        A structure denoting the system-imposed minimum and maximum string length (for text-based core types) or numeric values (for number-based) core types.  For example, the validationLimits for a text-based core type specify the min/max values for a minimum string length (minLength) constraint supplied by a schemaauthor on a text field.  Similarly, the maxLength's min/max specifies maximum string length constraint supplied by a schema author for the same field.

        :param validation_limits: The validation_limits of this Coretype.
        :type: ValidationLimits
        """
        
        self._validation_limits = validation_limits

    @property
    def item_validation_fields(self):
        """
        Gets the item_validation_fields of this Coretype.
        Specific to the \"tag\" core type, this is an array of strings naming the tag item fields of the core type subject to validation

        :return: The item_validation_fields of this Coretype.
        :rtype: list[str]
        """
        return self._item_validation_fields

    @item_validation_fields.setter
    def item_validation_fields(self, item_validation_fields):
        """
        Sets the item_validation_fields of this Coretype.
        Specific to the \"tag\" core type, this is an array of strings naming the tag item fields of the core type subject to validation

        :param item_validation_fields: The item_validation_fields of this Coretype.
        :type: list[str]
        """
        
        self._item_validation_fields = item_validation_fields

    @property
    def item_validation_limits(self):
        """
        Gets the item_validation_limits of this Coretype.
        A structure denoting the system-imposed minimum and maximum string length for string-array based core types such as \"tag\" and \"enum\".  Forexample, the validationLimits for a schema field using a tag core type specify the min/max values for a minimum string length (minLength) constraint supplied by a schema author on individual tags.  Similarly, the maxLength's min/max specifies maximum string length constraint supplied by a schema author for the same field's tags.

        :return: The item_validation_limits of this Coretype.
        :rtype: ItemValidationLimits
        """
        return self._item_validation_limits

    @item_validation_limits.setter
    def item_validation_limits(self, item_validation_limits):
        """
        Sets the item_validation_limits of this Coretype.
        A structure denoting the system-imposed minimum and maximum string length for string-array based core types such as \"tag\" and \"enum\".  Forexample, the validationLimits for a schema field using a tag core type specify the min/max values for a minimum string length (minLength) constraint supplied by a schema author on individual tags.  Similarly, the maxLength's min/max specifies maximum string length constraint supplied by a schema author for the same field's tags.

        :param item_validation_limits: The item_validation_limits of this Coretype.
        :type: ItemValidationLimits
        """
        
        self._item_validation_limits = item_validation_limits

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Coretype.
        The URI for this object

        :return: The self_uri of this Coretype.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Coretype.
        The URI for this object

        :param self_uri: The self_uri of this Coretype.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ManagementUnit(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ManagementUnit - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'division': 'Division',
            'business_unit': 'BusinessUnitReference',
            'start_day_of_week': 'str',
            'time_zone': 'str',
            'settings': 'ManagementUnitSettingsResponse',
            'metadata': 'WfmVersionedEntityMetadata',
            'version': 'int',
            'date_modified': 'datetime',
            'modified_by': 'UserReference',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'division': 'division',
            'business_unit': 'businessUnit',
            'start_day_of_week': 'startDayOfWeek',
            'time_zone': 'timeZone',
            'settings': 'settings',
            'metadata': 'metadata',
            'version': 'version',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._division = None
        self._business_unit = None
        self._start_day_of_week = None
        self._time_zone = None
        self._settings = None
        self._metadata = None
        self._version = None
        self._date_modified = None
        self._modified_by = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ManagementUnit.
        The globally unique identifier for the object.

        :return: The id of this ManagementUnit.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ManagementUnit.
        The globally unique identifier for the object.

        :param id: The id of this ManagementUnit.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ManagementUnit.


        :return: The name of this ManagementUnit.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ManagementUnit.


        :param name: The name of this ManagementUnit.
        :type: str
        """
        
        self._name = name

    @property
    def division(self):
        """
        Gets the division of this ManagementUnit.
        The division to which this entity belongs.

        :return: The division of this ManagementUnit.
        :rtype: Division
        """
        return self._division

    @division.setter
    def division(self, division):
        """
        Sets the division of this ManagementUnit.
        The division to which this entity belongs.

        :param division: The division of this ManagementUnit.
        :type: Division
        """
        
        self._division = division

    @property
    def business_unit(self):
        """
        Gets the business_unit of this ManagementUnit.
        The business unit to which this management unit belongs

        :return: The business_unit of this ManagementUnit.
        :rtype: BusinessUnitReference
        """
        return self._business_unit

    @business_unit.setter
    def business_unit(self, business_unit):
        """
        Sets the business_unit of this ManagementUnit.
        The business unit to which this management unit belongs

        :param business_unit: The business_unit of this ManagementUnit.
        :type: BusinessUnitReference
        """
        
        self._business_unit = business_unit

    @property
    def start_day_of_week(self):
        """
        Gets the start_day_of_week of this ManagementUnit.
        Start day of week for scheduling and forecasting purposes. Moving to Business Unit

        :return: The start_day_of_week of this ManagementUnit.
        :rtype: str
        """
        return self._start_day_of_week

    @start_day_of_week.setter
    def start_day_of_week(self, start_day_of_week):
        """
        Sets the start_day_of_week of this ManagementUnit.
        Start day of week for scheduling and forecasting purposes. Moving to Business Unit

        :param start_day_of_week: The start_day_of_week of this ManagementUnit.
        :type: str
        """
        allowed_values = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"]
        if start_day_of_week.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for start_day_of_week -> " + start_day_of_week)
            self._start_day_of_week = "outdated_sdk_version"
        else:
            self._start_day_of_week = start_day_of_week

    @property
    def time_zone(self):
        """
        Gets the time_zone of this ManagementUnit.
        The time zone for the management unit in standard Olson format.  Moving to Business Unit

        :return: The time_zone of this ManagementUnit.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this ManagementUnit.
        The time zone for the management unit in standard Olson format.  Moving to Business Unit

        :param time_zone: The time_zone of this ManagementUnit.
        :type: str
        """
        
        self._time_zone = time_zone

    @property
    def settings(self):
        """
        Gets the settings of this ManagementUnit.
        The configuration settings for this management unit

        :return: The settings of this ManagementUnit.
        :rtype: ManagementUnitSettingsResponse
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """
        Sets the settings of this ManagementUnit.
        The configuration settings for this management unit

        :param settings: The settings of this ManagementUnit.
        :type: ManagementUnitSettingsResponse
        """
        
        self._settings = settings

    @property
    def metadata(self):
        """
        Gets the metadata of this ManagementUnit.
        Version info metadata for this management unit. Deprecated, use settings.metadata

        :return: The metadata of this ManagementUnit.
        :rtype: WfmVersionedEntityMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this ManagementUnit.
        Version info metadata for this management unit. Deprecated, use settings.metadata

        :param metadata: The metadata of this ManagementUnit.
        :type: WfmVersionedEntityMetadata
        """
        
        self._metadata = metadata

    @property
    def version(self):
        """
        Gets the version of this ManagementUnit.
        The version of the underlying entity.  Deprecated, use field from settings.metadata instead

        :return: The version of this ManagementUnit.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ManagementUnit.
        The version of the underlying entity.  Deprecated, use field from settings.metadata instead

        :param version: The version of this ManagementUnit.
        :type: int
        """
        
        self._version = version

    @property
    def date_modified(self):
        """
        Gets the date_modified of this ManagementUnit.
        The date and time at which this entity was last modified.  Deprecated, use field from settings.metadata instead. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this ManagementUnit.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this ManagementUnit.
        The date and time at which this entity was last modified.  Deprecated, use field from settings.metadata instead. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this ManagementUnit.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this ManagementUnit.
        The user who last modified this entity.  Deprecated, use field from settings.metadata instead

        :return: The modified_by of this ManagementUnit.
        :rtype: UserReference
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this ManagementUnit.
        The user who last modified this entity.  Deprecated, use field from settings.metadata instead

        :param modified_by: The modified_by of this ManagementUnit.
        :type: UserReference
        """
        
        self._modified_by = modified_by

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ManagementUnit.
        The URI for this object

        :return: The self_uri of this ManagementUnit.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ManagementUnit.
        The URI for this object

        :param self_uri: The self_uri of this ManagementUnit.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DialerCampaignProgressEventCampaignProgress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerCampaignProgressEventCampaignProgress - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'campaign': 'DialerCampaignProgressEventUriReference',
            'number_of_contacts_called': 'float',
            'number_of_contacts_messaged': 'float',
            'total_number_of_contacts': 'float',
            'percentage': 'int',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'campaign': 'campaign',
            'number_of_contacts_called': 'numberOfContactsCalled',
            'number_of_contacts_messaged': 'numberOfContactsMessaged',
            'total_number_of_contacts': 'totalNumberOfContacts',
            'percentage': 'percentage',
            'additional_properties': 'additionalProperties'
        }

        self._campaign = None
        self._number_of_contacts_called = None
        self._number_of_contacts_messaged = None
        self._total_number_of_contacts = None
        self._percentage = None
        self._additional_properties = None

    @property
    def campaign(self):
        """
        Gets the campaign of this DialerCampaignProgressEventCampaignProgress.


        :return: The campaign of this DialerCampaignProgressEventCampaignProgress.
        :rtype: DialerCampaignProgressEventUriReference
        """
        return self._campaign

    @campaign.setter
    def campaign(self, campaign):
        """
        Sets the campaign of this DialerCampaignProgressEventCampaignProgress.


        :param campaign: The campaign of this DialerCampaignProgressEventCampaignProgress.
        :type: DialerCampaignProgressEventUriReference
        """
        
        self._campaign = campaign

    @property
    def number_of_contacts_called(self):
        """
        Gets the number_of_contacts_called of this DialerCampaignProgressEventCampaignProgress.


        :return: The number_of_contacts_called of this DialerCampaignProgressEventCampaignProgress.
        :rtype: float
        """
        return self._number_of_contacts_called

    @number_of_contacts_called.setter
    def number_of_contacts_called(self, number_of_contacts_called):
        """
        Sets the number_of_contacts_called of this DialerCampaignProgressEventCampaignProgress.


        :param number_of_contacts_called: The number_of_contacts_called of this DialerCampaignProgressEventCampaignProgress.
        :type: float
        """
        
        self._number_of_contacts_called = number_of_contacts_called

    @property
    def number_of_contacts_messaged(self):
        """
        Gets the number_of_contacts_messaged of this DialerCampaignProgressEventCampaignProgress.


        :return: The number_of_contacts_messaged of this DialerCampaignProgressEventCampaignProgress.
        :rtype: float
        """
        return self._number_of_contacts_messaged

    @number_of_contacts_messaged.setter
    def number_of_contacts_messaged(self, number_of_contacts_messaged):
        """
        Sets the number_of_contacts_messaged of this DialerCampaignProgressEventCampaignProgress.


        :param number_of_contacts_messaged: The number_of_contacts_messaged of this DialerCampaignProgressEventCampaignProgress.
        :type: float
        """
        
        self._number_of_contacts_messaged = number_of_contacts_messaged

    @property
    def total_number_of_contacts(self):
        """
        Gets the total_number_of_contacts of this DialerCampaignProgressEventCampaignProgress.


        :return: The total_number_of_contacts of this DialerCampaignProgressEventCampaignProgress.
        :rtype: float
        """
        return self._total_number_of_contacts

    @total_number_of_contacts.setter
    def total_number_of_contacts(self, total_number_of_contacts):
        """
        Sets the total_number_of_contacts of this DialerCampaignProgressEventCampaignProgress.


        :param total_number_of_contacts: The total_number_of_contacts of this DialerCampaignProgressEventCampaignProgress.
        :type: float
        """
        
        self._total_number_of_contacts = total_number_of_contacts

    @property
    def percentage(self):
        """
        Gets the percentage of this DialerCampaignProgressEventCampaignProgress.


        :return: The percentage of this DialerCampaignProgressEventCampaignProgress.
        :rtype: int
        """
        return self._percentage

    @percentage.setter
    def percentage(self, percentage):
        """
        Sets the percentage of this DialerCampaignProgressEventCampaignProgress.


        :param percentage: The percentage of this DialerCampaignProgressEventCampaignProgress.
        :type: int
        """
        
        self._percentage = percentage

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this DialerCampaignProgressEventCampaignProgress.


        :return: The additional_properties of this DialerCampaignProgressEventCampaignProgress.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this DialerCampaignProgressEventCampaignProgress.


        :param additional_properties: The additional_properties of this DialerCampaignProgressEventCampaignProgress.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WorkdayValuesTrend(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WorkdayValuesTrend - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'date_start_workday': 'date',
            'date_end_workday': 'date',
            'division': 'Division',
            'user': 'UserReference',
            'timezone': 'str',
            'results': 'list[WorkdayValuesMetricItem]'
        }

        self.attribute_map = {
            'date_start_workday': 'dateStartWorkday',
            'date_end_workday': 'dateEndWorkday',
            'division': 'division',
            'user': 'user',
            'timezone': 'timezone',
            'results': 'results'
        }

        self._date_start_workday = None
        self._date_end_workday = None
        self._division = None
        self._user = None
        self._timezone = None
        self._results = None

    @property
    def date_start_workday(self):
        """
        Gets the date_start_workday of this WorkdayValuesTrend.
        The start workday for the query range for the metric value trend. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :return: The date_start_workday of this WorkdayValuesTrend.
        :rtype: date
        """
        return self._date_start_workday

    @date_start_workday.setter
    def date_start_workday(self, date_start_workday):
        """
        Sets the date_start_workday of this WorkdayValuesTrend.
        The start workday for the query range for the metric value trend. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :param date_start_workday: The date_start_workday of this WorkdayValuesTrend.
        :type: date
        """
        
        self._date_start_workday = date_start_workday

    @property
    def date_end_workday(self):
        """
        Gets the date_end_workday of this WorkdayValuesTrend.
        The end workday for the query range for the metric value trend. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :return: The date_end_workday of this WorkdayValuesTrend.
        :rtype: date
        """
        return self._date_end_workday

    @date_end_workday.setter
    def date_end_workday(self, date_end_workday):
        """
        Sets the date_end_workday of this WorkdayValuesTrend.
        The end workday for the query range for the metric value trend. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :param date_end_workday: The date_end_workday of this WorkdayValuesTrend.
        :type: date
        """
        
        self._date_end_workday = date_end_workday

    @property
    def division(self):
        """
        Gets the division of this WorkdayValuesTrend.
        The targeted division for the query

        :return: The division of this WorkdayValuesTrend.
        :rtype: Division
        """
        return self._division

    @division.setter
    def division(self, division):
        """
        Sets the division of this WorkdayValuesTrend.
        The targeted division for the query

        :param division: The division of this WorkdayValuesTrend.
        :type: Division
        """
        
        self._division = division

    @property
    def user(self):
        """
        Gets the user of this WorkdayValuesTrend.
        The targeted user for the query

        :return: The user of this WorkdayValuesTrend.
        :rtype: UserReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this WorkdayValuesTrend.
        The targeted user for the query

        :param user: The user of this WorkdayValuesTrend.
        :type: UserReference
        """
        
        self._user = user

    @property
    def timezone(self):
        """
        Gets the timezone of this WorkdayValuesTrend.
        The time zone used for aggregating metric values

        :return: The timezone of this WorkdayValuesTrend.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this WorkdayValuesTrend.
        The time zone used for aggregating metric values

        :param timezone: The timezone of this WorkdayValuesTrend.
        :type: str
        """
        
        self._timezone = timezone

    @property
    def results(self):
        """
        Gets the results of this WorkdayValuesTrend.
        The metric value trends

        :return: The results of this WorkdayValuesTrend.
        :rtype: list[WorkdayValuesMetricItem]
        """
        return self._results

    @results.setter
    def results(self, results):
        """
        Sets the results of this WorkdayValuesTrend.
        The metric value trends

        :param results: The results of this WorkdayValuesTrend.
        :type: list[WorkdayValuesMetricItem]
        """
        
        self._results = results

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ContentManagementSingleDocumentTopicDocumentDataV2(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ContentManagementSingleDocumentTopicDocumentDataV2 - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'workspace': 'ContentManagementSingleDocumentTopicWorkspaceData',
            'created_by': 'ContentManagementSingleDocumentTopicUserData',
            'content_type': 'str',
            'content_length': 'int',
            'filename': 'str',
            'change_number': 'int',
            'date_uploaded': 'datetime',
            'uploaded_by': 'ContentManagementSingleDocumentTopicUserData',
            'lock_info': 'ContentManagementSingleDocumentTopicLockData',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'workspace': 'workspace',
            'created_by': 'createdBy',
            'content_type': 'contentType',
            'content_length': 'contentLength',
            'filename': 'filename',
            'change_number': 'changeNumber',
            'date_uploaded': 'dateUploaded',
            'uploaded_by': 'uploadedBy',
            'lock_info': 'lockInfo',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._workspace = None
        self._created_by = None
        self._content_type = None
        self._content_length = None
        self._filename = None
        self._change_number = None
        self._date_uploaded = None
        self._uploaded_by = None
        self._lock_info = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The id of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param id: The id of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The name of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param name: The name of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The date_created of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param date_created: The date_created of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The date_modified of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param date_modified: The date_modified of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def workspace(self):
        """
        Gets the workspace of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The workspace of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: ContentManagementSingleDocumentTopicWorkspaceData
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """
        Sets the workspace of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param workspace: The workspace of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: ContentManagementSingleDocumentTopicWorkspaceData
        """
        
        self._workspace = workspace

    @property
    def created_by(self):
        """
        Gets the created_by of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The created_by of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: ContentManagementSingleDocumentTopicUserData
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param created_by: The created_by of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: ContentManagementSingleDocumentTopicUserData
        """
        
        self._created_by = created_by

    @property
    def content_type(self):
        """
        Gets the content_type of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The content_type of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param content_type: The content_type of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: str
        """
        
        self._content_type = content_type

    @property
    def content_length(self):
        """
        Gets the content_length of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The content_length of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: int
        """
        return self._content_length

    @content_length.setter
    def content_length(self, content_length):
        """
        Sets the content_length of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param content_length: The content_length of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: int
        """
        
        self._content_length = content_length

    @property
    def filename(self):
        """
        Gets the filename of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The filename of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """
        Sets the filename of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param filename: The filename of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: str
        """
        
        self._filename = filename

    @property
    def change_number(self):
        """
        Gets the change_number of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The change_number of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: int
        """
        return self._change_number

    @change_number.setter
    def change_number(self, change_number):
        """
        Sets the change_number of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param change_number: The change_number of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: int
        """
        
        self._change_number = change_number

    @property
    def date_uploaded(self):
        """
        Gets the date_uploaded of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The date_uploaded of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: datetime
        """
        return self._date_uploaded

    @date_uploaded.setter
    def date_uploaded(self, date_uploaded):
        """
        Sets the date_uploaded of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param date_uploaded: The date_uploaded of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: datetime
        """
        
        self._date_uploaded = date_uploaded

    @property
    def uploaded_by(self):
        """
        Gets the uploaded_by of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The uploaded_by of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: ContentManagementSingleDocumentTopicUserData
        """
        return self._uploaded_by

    @uploaded_by.setter
    def uploaded_by(self, uploaded_by):
        """
        Sets the uploaded_by of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param uploaded_by: The uploaded_by of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: ContentManagementSingleDocumentTopicUserData
        """
        
        self._uploaded_by = uploaded_by

    @property
    def lock_info(self):
        """
        Gets the lock_info of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The lock_info of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: ContentManagementSingleDocumentTopicLockData
        """
        return self._lock_info

    @lock_info.setter
    def lock_info(self, lock_info):
        """
        Sets the lock_info of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param lock_info: The lock_info of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: ContentManagementSingleDocumentTopicLockData
        """
        
        self._lock_info = lock_info

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :return: The self_uri of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ContentManagementSingleDocumentTopicDocumentDataV2.


        :param self_uri: The self_uri of this ContentManagementSingleDocumentTopicDocumentDataV2.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DialerAction(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerAction - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'action_type_name': 'str',
            'update_option': 'str',
            'properties': 'dict(str, str)'
        }

        self.attribute_map = {
            'type': 'type',
            'action_type_name': 'actionTypeName',
            'update_option': 'updateOption',
            'properties': 'properties'
        }

        self._type = None
        self._action_type_name = None
        self._update_option = None
        self._properties = None

    @property
    def type(self):
        """
        Gets the type of this DialerAction.
        The type of this DialerAction.

        :return: The type of this DialerAction.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this DialerAction.
        The type of this DialerAction.

        :param type: The type of this DialerAction.
        :type: str
        """
        allowed_values = ["Action", "modifyContactAttribute"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def action_type_name(self):
        """
        Gets the action_type_name of this DialerAction.
        Additional type specification for this DialerAction.

        :return: The action_type_name of this DialerAction.
        :rtype: str
        """
        return self._action_type_name

    @action_type_name.setter
    def action_type_name(self, action_type_name):
        """
        Sets the action_type_name of this DialerAction.
        Additional type specification for this DialerAction.

        :param action_type_name: The action_type_name of this DialerAction.
        :type: str
        """
        allowed_values = ["DO_NOT_DIAL", "MODIFY_CONTACT_ATTRIBUTE", "SWITCH_TO_PREVIEW", "APPEND_NUMBER_TO_DNC_LIST", "SCHEDULE_CALLBACK", "CONTACT_UNCALLABLE", "NUMBER_UNCALLABLE", "SET_CALLER_ID", "SET_SKILLS"]
        if action_type_name.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for action_type_name -> " + action_type_name)
            self._action_type_name = "outdated_sdk_version"
        else:
            self._action_type_name = action_type_name

    @property
    def update_option(self):
        """
        Gets the update_option of this DialerAction.
        Specifies how a contact attribute should be updated. Required for MODIFY_CONTACT_ATTRIBUTE.

        :return: The update_option of this DialerAction.
        :rtype: str
        """
        return self._update_option

    @update_option.setter
    def update_option(self, update_option):
        """
        Sets the update_option of this DialerAction.
        Specifies how a contact attribute should be updated. Required for MODIFY_CONTACT_ATTRIBUTE.

        :param update_option: The update_option of this DialerAction.
        :type: str
        """
        allowed_values = ["SET", "INCREMENT", "DECREMENT", "CURRENT_TIME"]
        if update_option.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for update_option -> " + update_option)
            self._update_option = "outdated_sdk_version"
        else:
            self._update_option = update_option

    @property
    def properties(self):
        """
        Gets the properties of this DialerAction.
        A map of key-value pairs pertinent to the DialerAction. Different types of DialerActions require different properties. MODIFY_CONTACT_ATTRIBUTE with an updateOption of SET takes a contact column as the key and accepts any value. SCHEDULE_CALLBACK takes a key 'callbackOffset' that specifies how far in the future the callback should be scheduled, in minutes. SET_CALLER_ID takes two keys: 'callerAddress', which should be the caller id phone number, and 'callerName'. For either key, you can also specify a column on the contact to get the value from. To do this, specify 'contact.Column', where 'Column' is the name of the contact column from which to get the value. SET_SKILLS takes a key 'skills' with an array of skill ids wrapped into a string (Example: {'skills': '['skillIdHere']'} ).

        :return: The properties of this DialerAction.
        :rtype: dict(str, str)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this DialerAction.
        A map of key-value pairs pertinent to the DialerAction. Different types of DialerActions require different properties. MODIFY_CONTACT_ATTRIBUTE with an updateOption of SET takes a contact column as the key and accepts any value. SCHEDULE_CALLBACK takes a key 'callbackOffset' that specifies how far in the future the callback should be scheduled, in minutes. SET_CALLER_ID takes two keys: 'callerAddress', which should be the caller id phone number, and 'callerName'. For either key, you can also specify a column on the contact to get the value from. To do this, specify 'contact.Column', where 'Column' is the name of the contact column from which to get the value. SET_SKILLS takes a key 'skills' with an array of skill ids wrapped into a string (Example: {'skills': '['skillIdHere']'} ).

        :param properties: The properties of this DialerAction.
        :type: dict(str, str)
        """
        
        self._properties = properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CallHistoryConversation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CallHistoryConversation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'participants': 'list[CallHistoryParticipant]',
            'direction': 'str',
            'went_to_voicemail': 'bool',
            'missed_call': 'bool',
            'start_time': 'datetime',
            'was_conference': 'bool',
            'was_callback': 'bool',
            'had_screen_share': 'bool',
            'had_cobrowse': 'bool',
            'was_outbound_campaign': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'participants': 'participants',
            'direction': 'direction',
            'went_to_voicemail': 'wentToVoicemail',
            'missed_call': 'missedCall',
            'start_time': 'startTime',
            'was_conference': 'wasConference',
            'was_callback': 'wasCallback',
            'had_screen_share': 'hadScreenShare',
            'had_cobrowse': 'hadCobrowse',
            'was_outbound_campaign': 'wasOutboundCampaign',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._participants = None
        self._direction = None
        self._went_to_voicemail = None
        self._missed_call = None
        self._start_time = None
        self._was_conference = None
        self._was_callback = None
        self._had_screen_share = None
        self._had_cobrowse = None
        self._was_outbound_campaign = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this CallHistoryConversation.
        The globally unique identifier for the object.

        :return: The id of this CallHistoryConversation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CallHistoryConversation.
        The globally unique identifier for the object.

        :param id: The id of this CallHistoryConversation.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this CallHistoryConversation.


        :return: The name of this CallHistoryConversation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CallHistoryConversation.


        :param name: The name of this CallHistoryConversation.
        :type: str
        """
        
        self._name = name

    @property
    def participants(self):
        """
        Gets the participants of this CallHistoryConversation.
        The list of participants involved in the conversation.

        :return: The participants of this CallHistoryConversation.
        :rtype: list[CallHistoryParticipant]
        """
        return self._participants

    @participants.setter
    def participants(self, participants):
        """
        Sets the participants of this CallHistoryConversation.
        The list of participants involved in the conversation.

        :param participants: The participants of this CallHistoryConversation.
        :type: list[CallHistoryParticipant]
        """
        
        self._participants = participants

    @property
    def direction(self):
        """
        Gets the direction of this CallHistoryConversation.
        The direction of the call relating to the current user

        :return: The direction of this CallHistoryConversation.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this CallHistoryConversation.
        The direction of the call relating to the current user

        :param direction: The direction of this CallHistoryConversation.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def went_to_voicemail(self):
        """
        Gets the went_to_voicemail of this CallHistoryConversation.
        Did the call end in the current user's voicemail

        :return: The went_to_voicemail of this CallHistoryConversation.
        :rtype: bool
        """
        return self._went_to_voicemail

    @went_to_voicemail.setter
    def went_to_voicemail(self, went_to_voicemail):
        """
        Sets the went_to_voicemail of this CallHistoryConversation.
        Did the call end in the current user's voicemail

        :param went_to_voicemail: The went_to_voicemail of this CallHistoryConversation.
        :type: bool
        """
        
        self._went_to_voicemail = went_to_voicemail

    @property
    def missed_call(self):
        """
        Gets the missed_call of this CallHistoryConversation.
        Did the user not answer this conversation

        :return: The missed_call of this CallHistoryConversation.
        :rtype: bool
        """
        return self._missed_call

    @missed_call.setter
    def missed_call(self, missed_call):
        """
        Sets the missed_call of this CallHistoryConversation.
        Did the user not answer this conversation

        :param missed_call: The missed_call of this CallHistoryConversation.
        :type: bool
        """
        
        self._missed_call = missed_call

    @property
    def start_time(self):
        """
        Gets the start_time of this CallHistoryConversation.
        The time the user joined the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_time of this CallHistoryConversation.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this CallHistoryConversation.
        The time the user joined the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_time: The start_time of this CallHistoryConversation.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def was_conference(self):
        """
        Gets the was_conference of this CallHistoryConversation.
        Was this conversation a conference

        :return: The was_conference of this CallHistoryConversation.
        :rtype: bool
        """
        return self._was_conference

    @was_conference.setter
    def was_conference(self, was_conference):
        """
        Sets the was_conference of this CallHistoryConversation.
        Was this conversation a conference

        :param was_conference: The was_conference of this CallHistoryConversation.
        :type: bool
        """
        
        self._was_conference = was_conference

    @property
    def was_callback(self):
        """
        Gets the was_callback of this CallHistoryConversation.
        Was this conversation a callback

        :return: The was_callback of this CallHistoryConversation.
        :rtype: bool
        """
        return self._was_callback

    @was_callback.setter
    def was_callback(self, was_callback):
        """
        Sets the was_callback of this CallHistoryConversation.
        Was this conversation a callback

        :param was_callback: The was_callback of this CallHistoryConversation.
        :type: bool
        """
        
        self._was_callback = was_callback

    @property
    def had_screen_share(self):
        """
        Gets the had_screen_share of this CallHistoryConversation.
        Did this conversation have a screen share session

        :return: The had_screen_share of this CallHistoryConversation.
        :rtype: bool
        """
        return self._had_screen_share

    @had_screen_share.setter
    def had_screen_share(self, had_screen_share):
        """
        Sets the had_screen_share of this CallHistoryConversation.
        Did this conversation have a screen share session

        :param had_screen_share: The had_screen_share of this CallHistoryConversation.
        :type: bool
        """
        
        self._had_screen_share = had_screen_share

    @property
    def had_cobrowse(self):
        """
        Gets the had_cobrowse of this CallHistoryConversation.
        Did this conversation have a cobrowse session

        :return: The had_cobrowse of this CallHistoryConversation.
        :rtype: bool
        """
        return self._had_cobrowse

    @had_cobrowse.setter
    def had_cobrowse(self, had_cobrowse):
        """
        Sets the had_cobrowse of this CallHistoryConversation.
        Did this conversation have a cobrowse session

        :param had_cobrowse: The had_cobrowse of this CallHistoryConversation.
        :type: bool
        """
        
        self._had_cobrowse = had_cobrowse

    @property
    def was_outbound_campaign(self):
        """
        Gets the was_outbound_campaign of this CallHistoryConversation.
        Was this conversation associated with an outbound campaign

        :return: The was_outbound_campaign of this CallHistoryConversation.
        :rtype: bool
        """
        return self._was_outbound_campaign

    @was_outbound_campaign.setter
    def was_outbound_campaign(self, was_outbound_campaign):
        """
        Sets the was_outbound_campaign of this CallHistoryConversation.
        Was this conversation associated with an outbound campaign

        :param was_outbound_campaign: The was_outbound_campaign of this CallHistoryConversation.
        :type: bool
        """
        
        self._was_outbound_campaign = was_outbound_campaign

    @property
    def self_uri(self):
        """
        Gets the self_uri of this CallHistoryConversation.
        The URI for this object

        :return: The self_uri of this CallHistoryConversation.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this CallHistoryConversation.
        The URI for this object

        :param self_uri: The self_uri of this CallHistoryConversation.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CopyVoicemailMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CopyVoicemailMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'voicemail_message_id': 'str',
            'user_id': 'str',
            'group_id': 'str'
        }

        self.attribute_map = {
            'voicemail_message_id': 'voicemailMessageId',
            'user_id': 'userId',
            'group_id': 'groupId'
        }

        self._voicemail_message_id = None
        self._user_id = None
        self._group_id = None

    @property
    def voicemail_message_id(self):
        """
        Gets the voicemail_message_id of this CopyVoicemailMessage.
        The id of the VoicemailMessage to copy

        :return: The voicemail_message_id of this CopyVoicemailMessage.
        :rtype: str
        """
        return self._voicemail_message_id

    @voicemail_message_id.setter
    def voicemail_message_id(self, voicemail_message_id):
        """
        Sets the voicemail_message_id of this CopyVoicemailMessage.
        The id of the VoicemailMessage to copy

        :param voicemail_message_id: The voicemail_message_id of this CopyVoicemailMessage.
        :type: str
        """
        
        self._voicemail_message_id = voicemail_message_id

    @property
    def user_id(self):
        """
        Gets the user_id of this CopyVoicemailMessage.
        The id of the User to copy the VoicemailMessage to

        :return: The user_id of this CopyVoicemailMessage.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this CopyVoicemailMessage.
        The id of the User to copy the VoicemailMessage to

        :param user_id: The user_id of this CopyVoicemailMessage.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def group_id(self):
        """
        Gets the group_id of this CopyVoicemailMessage.
        The id of the Group to copy the VoicemailMessage to

        :return: The group_id of this CopyVoicemailMessage.
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """
        Sets the group_id of this CopyVoicemailMessage.
        The id of the Group to copy the VoicemailMessage to

        :param group_id: The group_id of this CopyVoicemailMessage.
        :type: str
        """
        
        self._group_id = group_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Change(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Change - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'entity': 'AuditEntity',
            'pcProperty': 'str',
            'old_values': 'list[str]',
            'new_values': 'list[str]'
        }

        self.attribute_map = {
            'entity': 'entity',
            'pcProperty': 'property',
            'old_values': 'oldValues',
            'new_values': 'newValues'
        }

        self._entity = None
        self._pcProperty = None
        self._old_values = None
        self._new_values = None

    @property
    def entity(self):
        """
        Gets the entity of this Change.


        :return: The entity of this Change.
        :rtype: AuditEntity
        """
        return self._entity

    @entity.setter
    def entity(self, entity):
        """
        Sets the entity of this Change.


        :param entity: The entity of this Change.
        :type: AuditEntity
        """
        
        self._entity = entity

    @property
    def pcProperty(self):
        """
        Gets the pcProperty of this Change.
        The property that was changed

        :return: The pcProperty of this Change.
        :rtype: str
        """
        return self._pcProperty

    @pcProperty.setter
    def pcProperty(self, pcProperty):
        """
        Sets the pcProperty of this Change.
        The property that was changed

        :param pcProperty: The pcProperty of this Change.
        :type: str
        """
        
        self._pcProperty = pcProperty

    @property
    def old_values(self):
        """
        Gets the old_values of this Change.
        The old values which were modified and/or removed by this action.

        :return: The old_values of this Change.
        :rtype: list[str]
        """
        return self._old_values

    @old_values.setter
    def old_values(self, old_values):
        """
        Sets the old_values of this Change.
        The old values which were modified and/or removed by this action.

        :param old_values: The old_values of this Change.
        :type: list[str]
        """
        
        self._old_values = old_values

    @property
    def new_values(self):
        """
        Gets the new_values of this Change.
        The new values which were modified and/or added by this action.

        :return: The new_values of this Change.
        :rtype: list[str]
        """
        return self._new_values

    @new_values.setter
    def new_values(self, new_values):
        """
        Sets the new_values of this Change.
        The new values which were modified and/or added by this action.

        :param new_values: The new_values of this Change.
        :type: list[str]
        """
        
        self._new_values = new_values

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class EmergencyCallFlow(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EmergencyCallFlow - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'emergency_flow': 'DomainEntityRef',
            'ivrs': 'list[DomainEntityRef]'
        }

        self.attribute_map = {
            'emergency_flow': 'emergencyFlow',
            'ivrs': 'ivrs'
        }

        self._emergency_flow = None
        self._ivrs = None

    @property
    def emergency_flow(self):
        """
        Gets the emergency_flow of this EmergencyCallFlow.
        The call flow to execute in an emergency.

        :return: The emergency_flow of this EmergencyCallFlow.
        :rtype: DomainEntityRef
        """
        return self._emergency_flow

    @emergency_flow.setter
    def emergency_flow(self, emergency_flow):
        """
        Sets the emergency_flow of this EmergencyCallFlow.
        The call flow to execute in an emergency.

        :param emergency_flow: The emergency_flow of this EmergencyCallFlow.
        :type: DomainEntityRef
        """
        
        self._emergency_flow = emergency_flow

    @property
    def ivrs(self):
        """
        Gets the ivrs of this EmergencyCallFlow.
        The IVR(s) to route to the call flow during an emergency.

        :return: The ivrs of this EmergencyCallFlow.
        :rtype: list[DomainEntityRef]
        """
        return self._ivrs

    @ivrs.setter
    def ivrs(self, ivrs):
        """
        Sets the ivrs of this EmergencyCallFlow.
        The IVR(s) to route to the call flow during an emergency.

        :param ivrs: The ivrs of this EmergencyCallFlow.
        :type: list[DomainEntityRef]
        """
        
        self._ivrs = ivrs

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BuRescheduleRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BuRescheduleRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'start_date': 'datetime',
            'end_date': 'datetime',
            'agent_ids': 'list[str]',
            'activity_code_ids': 'list[str]',
            'management_unit_ids': 'list[str]',
            'do_not_change_weekly_paid_time': 'bool',
            'do_not_change_daily_paid_time': 'bool',
            'do_not_change_shift_start_times': 'bool',
            'do_not_change_manually_edited_shifts': 'bool'
        }

        self.attribute_map = {
            'start_date': 'startDate',
            'end_date': 'endDate',
            'agent_ids': 'agentIds',
            'activity_code_ids': 'activityCodeIds',
            'management_unit_ids': 'managementUnitIds',
            'do_not_change_weekly_paid_time': 'doNotChangeWeeklyPaidTime',
            'do_not_change_daily_paid_time': 'doNotChangeDailyPaidTime',
            'do_not_change_shift_start_times': 'doNotChangeShiftStartTimes',
            'do_not_change_manually_edited_shifts': 'doNotChangeManuallyEditedShifts'
        }

        self._start_date = None
        self._end_date = None
        self._agent_ids = None
        self._activity_code_ids = None
        self._management_unit_ids = None
        self._do_not_change_weekly_paid_time = None
        self._do_not_change_daily_paid_time = None
        self._do_not_change_shift_start_times = None
        self._do_not_change_manually_edited_shifts = None

    @property
    def start_date(self):
        """
        Gets the start_date of this BuRescheduleRequest.
        The start of the range to reschedule.  Defaults to the beginning of the schedule. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_date of this BuRescheduleRequest.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this BuRescheduleRequest.
        The start of the range to reschedule.  Defaults to the beginning of the schedule. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_date: The start_date of this BuRescheduleRequest.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this BuRescheduleRequest.
        The end of the range to reschedule.  Defaults the the end of the schedule. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The end_date of this BuRescheduleRequest.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this BuRescheduleRequest.
        The end of the range to reschedule.  Defaults the the end of the schedule. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param end_date: The end_date of this BuRescheduleRequest.
        :type: datetime
        """
        
        self._end_date = end_date

    @property
    def agent_ids(self):
        """
        Gets the agent_ids of this BuRescheduleRequest.
        The IDs of the agents to consider for rescheduling.  Omit to consider all agents in the specified management units.Agents not in the specified management units will be ignored

        :return: The agent_ids of this BuRescheduleRequest.
        :rtype: list[str]
        """
        return self._agent_ids

    @agent_ids.setter
    def agent_ids(self, agent_ids):
        """
        Sets the agent_ids of this BuRescheduleRequest.
        The IDs of the agents to consider for rescheduling.  Omit to consider all agents in the specified management units.Agents not in the specified management units will be ignored

        :param agent_ids: The agent_ids of this BuRescheduleRequest.
        :type: list[str]
        """
        
        self._agent_ids = agent_ids

    @property
    def activity_code_ids(self):
        """
        Gets the activity_code_ids of this BuRescheduleRequest.
        The IDs of the activity codes to consider for rescheduling.  Omit to consider all activity codes

        :return: The activity_code_ids of this BuRescheduleRequest.
        :rtype: list[str]
        """
        return self._activity_code_ids

    @activity_code_ids.setter
    def activity_code_ids(self, activity_code_ids):
        """
        Sets the activity_code_ids of this BuRescheduleRequest.
        The IDs of the activity codes to consider for rescheduling.  Omit to consider all activity codes

        :param activity_code_ids: The activity_code_ids of this BuRescheduleRequest.
        :type: list[str]
        """
        
        self._activity_code_ids = activity_code_ids

    @property
    def management_unit_ids(self):
        """
        Gets the management_unit_ids of this BuRescheduleRequest.
        The IDs of the management units to reschedule

        :return: The management_unit_ids of this BuRescheduleRequest.
        :rtype: list[str]
        """
        return self._management_unit_ids

    @management_unit_ids.setter
    def management_unit_ids(self, management_unit_ids):
        """
        Sets the management_unit_ids of this BuRescheduleRequest.
        The IDs of the management units to reschedule

        :param management_unit_ids: The management_unit_ids of this BuRescheduleRequest.
        :type: list[str]
        """
        
        self._management_unit_ids = management_unit_ids

    @property
    def do_not_change_weekly_paid_time(self):
        """
        Gets the do_not_change_weekly_paid_time of this BuRescheduleRequest.
        Instructs the scheduler whether it is allowed to change weekly paid time

        :return: The do_not_change_weekly_paid_time of this BuRescheduleRequest.
        :rtype: bool
        """
        return self._do_not_change_weekly_paid_time

    @do_not_change_weekly_paid_time.setter
    def do_not_change_weekly_paid_time(self, do_not_change_weekly_paid_time):
        """
        Sets the do_not_change_weekly_paid_time of this BuRescheduleRequest.
        Instructs the scheduler whether it is allowed to change weekly paid time

        :param do_not_change_weekly_paid_time: The do_not_change_weekly_paid_time of this BuRescheduleRequest.
        :type: bool
        """
        
        self._do_not_change_weekly_paid_time = do_not_change_weekly_paid_time

    @property
    def do_not_change_daily_paid_time(self):
        """
        Gets the do_not_change_daily_paid_time of this BuRescheduleRequest.
        Instructs the scheduler whether it is allowed to change daily paid time

        :return: The do_not_change_daily_paid_time of this BuRescheduleRequest.
        :rtype: bool
        """
        return self._do_not_change_daily_paid_time

    @do_not_change_daily_paid_time.setter
    def do_not_change_daily_paid_time(self, do_not_change_daily_paid_time):
        """
        Sets the do_not_change_daily_paid_time of this BuRescheduleRequest.
        Instructs the scheduler whether it is allowed to change daily paid time

        :param do_not_change_daily_paid_time: The do_not_change_daily_paid_time of this BuRescheduleRequest.
        :type: bool
        """
        
        self._do_not_change_daily_paid_time = do_not_change_daily_paid_time

    @property
    def do_not_change_shift_start_times(self):
        """
        Gets the do_not_change_shift_start_times of this BuRescheduleRequest.
        Instructs the scheduler whether it is allowed to change shift start times

        :return: The do_not_change_shift_start_times of this BuRescheduleRequest.
        :rtype: bool
        """
        return self._do_not_change_shift_start_times

    @do_not_change_shift_start_times.setter
    def do_not_change_shift_start_times(self, do_not_change_shift_start_times):
        """
        Sets the do_not_change_shift_start_times of this BuRescheduleRequest.
        Instructs the scheduler whether it is allowed to change shift start times

        :param do_not_change_shift_start_times: The do_not_change_shift_start_times of this BuRescheduleRequest.
        :type: bool
        """
        
        self._do_not_change_shift_start_times = do_not_change_shift_start_times

    @property
    def do_not_change_manually_edited_shifts(self):
        """
        Gets the do_not_change_manually_edited_shifts of this BuRescheduleRequest.
        Instructs the scheduler whether it is allowed to change manually edited shifts

        :return: The do_not_change_manually_edited_shifts of this BuRescheduleRequest.
        :rtype: bool
        """
        return self._do_not_change_manually_edited_shifts

    @do_not_change_manually_edited_shifts.setter
    def do_not_change_manually_edited_shifts(self, do_not_change_manually_edited_shifts):
        """
        Sets the do_not_change_manually_edited_shifts of this BuRescheduleRequest.
        Instructs the scheduler whether it is allowed to change manually edited shifts

        :param do_not_change_manually_edited_shifts: The do_not_change_manually_edited_shifts of this BuRescheduleRequest.
        :type: bool
        """
        
        self._do_not_change_manually_edited_shifts = do_not_change_manually_edited_shifts

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class PostTextResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PostTextResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'bot_state': 'str',
            'reply_messages': 'list[PostTextMessage]',
            'intent_name': 'str',
            'slots': 'dict(str, str)',
            'bot_correlation_id': 'str',
            'amazon_lex': 'dict(str, object)',
            'google_dialog_flow': 'dict(str, object)',
            'genesys_dialog_engine': 'dict(str, object)'
        }

        self.attribute_map = {
            'bot_state': 'botState',
            'reply_messages': 'replyMessages',
            'intent_name': 'intentName',
            'slots': 'slots',
            'bot_correlation_id': 'botCorrelationId',
            'amazon_lex': 'amazonLex',
            'google_dialog_flow': 'googleDialogFlow',
            'genesys_dialog_engine': 'genesysDialogEngine'
        }

        self._bot_state = None
        self._reply_messages = None
        self._intent_name = None
        self._slots = None
        self._bot_correlation_id = None
        self._amazon_lex = None
        self._google_dialog_flow = None
        self._genesys_dialog_engine = None

    @property
    def bot_state(self):
        """
        Gets the bot_state of this PostTextResponse.
        The state of the bot after completion of the request

        :return: The bot_state of this PostTextResponse.
        :rtype: str
        """
        return self._bot_state

    @bot_state.setter
    def bot_state(self, bot_state):
        """
        Sets the bot_state of this PostTextResponse.
        The state of the bot after completion of the request

        :param bot_state: The bot_state of this PostTextResponse.
        :type: str
        """
        allowed_values = ["Complete", "Failed", "MoreData"]
        if bot_state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for bot_state -> " + bot_state)
            self._bot_state = "outdated_sdk_version"
        else:
            self._bot_state = bot_state

    @property
    def reply_messages(self):
        """
        Gets the reply_messages of this PostTextResponse.
        The list of messages to respond with, if any

        :return: The reply_messages of this PostTextResponse.
        :rtype: list[PostTextMessage]
        """
        return self._reply_messages

    @reply_messages.setter
    def reply_messages(self, reply_messages):
        """
        Sets the reply_messages of this PostTextResponse.
        The list of messages to respond with, if any

        :param reply_messages: The reply_messages of this PostTextResponse.
        :type: list[PostTextMessage]
        """
        
        self._reply_messages = reply_messages

    @property
    def intent_name(self):
        """
        Gets the intent_name of this PostTextResponse.
        The name of the intent the bot is either processing or has processed, this will be blank if no intent could be detected.

        :return: The intent_name of this PostTextResponse.
        :rtype: str
        """
        return self._intent_name

    @intent_name.setter
    def intent_name(self, intent_name):
        """
        Sets the intent_name of this PostTextResponse.
        The name of the intent the bot is either processing or has processed, this will be blank if no intent could be detected.

        :param intent_name: The intent_name of this PostTextResponse.
        :type: str
        """
        
        self._intent_name = intent_name

    @property
    def slots(self):
        """
        Gets the slots of this PostTextResponse.
        Data parameters detected and filled by the bot.

        :return: The slots of this PostTextResponse.
        :rtype: dict(str, str)
        """
        return self._slots

    @slots.setter
    def slots(self, slots):
        """
        Sets the slots of this PostTextResponse.
        Data parameters detected and filled by the bot.

        :param slots: The slots of this PostTextResponse.
        :type: dict(str, str)
        """
        
        self._slots = slots

    @property
    def bot_correlation_id(self):
        """
        Gets the bot_correlation_id of this PostTextResponse.
        The optional ID specified in the request

        :return: The bot_correlation_id of this PostTextResponse.
        :rtype: str
        """
        return self._bot_correlation_id

    @bot_correlation_id.setter
    def bot_correlation_id(self, bot_correlation_id):
        """
        Sets the bot_correlation_id of this PostTextResponse.
        The optional ID specified in the request

        :param bot_correlation_id: The bot_correlation_id of this PostTextResponse.
        :type: str
        """
        
        self._bot_correlation_id = bot_correlation_id

    @property
    def amazon_lex(self):
        """
        Gets the amazon_lex of this PostTextResponse.
        Raw data response from AWS (if called)

        :return: The amazon_lex of this PostTextResponse.
        :rtype: dict(str, object)
        """
        return self._amazon_lex

    @amazon_lex.setter
    def amazon_lex(self, amazon_lex):
        """
        Sets the amazon_lex of this PostTextResponse.
        Raw data response from AWS (if called)

        :param amazon_lex: The amazon_lex of this PostTextResponse.
        :type: dict(str, object)
        """
        
        self._amazon_lex = amazon_lex

    @property
    def google_dialog_flow(self):
        """
        Gets the google_dialog_flow of this PostTextResponse.
        Raw data response from Google Dialogflow (if called)

        :return: The google_dialog_flow of this PostTextResponse.
        :rtype: dict(str, object)
        """
        return self._google_dialog_flow

    @google_dialog_flow.setter
    def google_dialog_flow(self, google_dialog_flow):
        """
        Sets the google_dialog_flow of this PostTextResponse.
        Raw data response from Google Dialogflow (if called)

        :param google_dialog_flow: The google_dialog_flow of this PostTextResponse.
        :type: dict(str, object)
        """
        
        self._google_dialog_flow = google_dialog_flow

    @property
    def genesys_dialog_engine(self):
        """
        Gets the genesys_dialog_engine of this PostTextResponse.
        Raw data response from Genesys' Dialogengine (if called)

        :return: The genesys_dialog_engine of this PostTextResponse.
        :rtype: dict(str, object)
        """
        return self._genesys_dialog_engine

    @genesys_dialog_engine.setter
    def genesys_dialog_engine(self, genesys_dialog_engine):
        """
        Sets the genesys_dialog_engine of this PostTextResponse.
        Raw data response from Genesys' Dialogengine (if called)

        :param genesys_dialog_engine: The genesys_dialog_engine of this PostTextResponse.
        :type: dict(str, object)
        """
        
        self._genesys_dialog_engine = genesys_dialog_engine

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SurveyQuestionScore(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SurveyQuestionScore - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'question_id': 'str',
            'answer_id': 'str',
            'score': 'int',
            'marked_na': 'bool',
            'nps_score': 'int',
            'nps_text_answer': 'str',
            'free_text_answer': 'str'
        }

        self.attribute_map = {
            'question_id': 'questionId',
            'answer_id': 'answerId',
            'score': 'score',
            'marked_na': 'markedNA',
            'nps_score': 'npsScore',
            'nps_text_answer': 'npsTextAnswer',
            'free_text_answer': 'freeTextAnswer'
        }

        self._question_id = None
        self._answer_id = None
        self._score = None
        self._marked_na = None
        self._nps_score = None
        self._nps_text_answer = None
        self._free_text_answer = None

    @property
    def question_id(self):
        """
        Gets the question_id of this SurveyQuestionScore.


        :return: The question_id of this SurveyQuestionScore.
        :rtype: str
        """
        return self._question_id

    @question_id.setter
    def question_id(self, question_id):
        """
        Sets the question_id of this SurveyQuestionScore.


        :param question_id: The question_id of this SurveyQuestionScore.
        :type: str
        """
        
        self._question_id = question_id

    @property
    def answer_id(self):
        """
        Gets the answer_id of this SurveyQuestionScore.


        :return: The answer_id of this SurveyQuestionScore.
        :rtype: str
        """
        return self._answer_id

    @answer_id.setter
    def answer_id(self, answer_id):
        """
        Sets the answer_id of this SurveyQuestionScore.


        :param answer_id: The answer_id of this SurveyQuestionScore.
        :type: str
        """
        
        self._answer_id = answer_id

    @property
    def score(self):
        """
        Gets the score of this SurveyQuestionScore.


        :return: The score of this SurveyQuestionScore.
        :rtype: int
        """
        return self._score

    @score.setter
    def score(self, score):
        """
        Sets the score of this SurveyQuestionScore.


        :param score: The score of this SurveyQuestionScore.
        :type: int
        """
        
        self._score = score

    @property
    def marked_na(self):
        """
        Gets the marked_na of this SurveyQuestionScore.


        :return: The marked_na of this SurveyQuestionScore.
        :rtype: bool
        """
        return self._marked_na

    @marked_na.setter
    def marked_na(self, marked_na):
        """
        Sets the marked_na of this SurveyQuestionScore.


        :param marked_na: The marked_na of this SurveyQuestionScore.
        :type: bool
        """
        
        self._marked_na = marked_na

    @property
    def nps_score(self):
        """
        Gets the nps_score of this SurveyQuestionScore.


        :return: The nps_score of this SurveyQuestionScore.
        :rtype: int
        """
        return self._nps_score

    @nps_score.setter
    def nps_score(self, nps_score):
        """
        Sets the nps_score of this SurveyQuestionScore.


        :param nps_score: The nps_score of this SurveyQuestionScore.
        :type: int
        """
        
        self._nps_score = nps_score

    @property
    def nps_text_answer(self):
        """
        Gets the nps_text_answer of this SurveyQuestionScore.


        :return: The nps_text_answer of this SurveyQuestionScore.
        :rtype: str
        """
        return self._nps_text_answer

    @nps_text_answer.setter
    def nps_text_answer(self, nps_text_answer):
        """
        Sets the nps_text_answer of this SurveyQuestionScore.


        :param nps_text_answer: The nps_text_answer of this SurveyQuestionScore.
        :type: str
        """
        
        self._nps_text_answer = nps_text_answer

    @property
    def free_text_answer(self):
        """
        Gets the free_text_answer of this SurveyQuestionScore.


        :return: The free_text_answer of this SurveyQuestionScore.
        :rtype: str
        """
        return self._free_text_answer

    @free_text_answer.setter
    def free_text_answer(self, free_text_answer):
        """
        Sets the free_text_answer of this SurveyQuestionScore.


        :param free_text_answer: The free_text_answer of this SurveyQuestionScore.
        :type: str
        """
        
        self._free_text_answer = free_text_answer

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmIntradayDataUpdateTopicIntradayDataUpdate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmIntradayDataUpdateTopicIntradayDataUpdate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'start_date': 'datetime',
            'end_date': 'datetime',
            'interval_length_minutes': 'int',
            'number_of_intervals': 'int',
            'metrics': 'list[WfmIntradayDataUpdateTopicIntradayMetric]',
            'queue_ids': 'list[str]',
            'intraday_data_groupings': 'list[WfmIntradayDataUpdateTopicIntradayDataGroup]'
        }

        self.attribute_map = {
            'start_date': 'startDate',
            'end_date': 'endDate',
            'interval_length_minutes': 'intervalLengthMinutes',
            'number_of_intervals': 'numberOfIntervals',
            'metrics': 'metrics',
            'queue_ids': 'queueIds',
            'intraday_data_groupings': 'intradayDataGroupings'
        }

        self._start_date = None
        self._end_date = None
        self._interval_length_minutes = None
        self._number_of_intervals = None
        self._metrics = None
        self._queue_ids = None
        self._intraday_data_groupings = None

    @property
    def start_date(self):
        """
        Gets the start_date of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :return: The start_date of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :param start_date: The start_date of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :return: The end_date of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :param end_date: The end_date of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :type: datetime
        """
        
        self._end_date = end_date

    @property
    def interval_length_minutes(self):
        """
        Gets the interval_length_minutes of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :return: The interval_length_minutes of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :rtype: int
        """
        return self._interval_length_minutes

    @interval_length_minutes.setter
    def interval_length_minutes(self, interval_length_minutes):
        """
        Sets the interval_length_minutes of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :param interval_length_minutes: The interval_length_minutes of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :type: int
        """
        
        self._interval_length_minutes = interval_length_minutes

    @property
    def number_of_intervals(self):
        """
        Gets the number_of_intervals of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :return: The number_of_intervals of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :rtype: int
        """
        return self._number_of_intervals

    @number_of_intervals.setter
    def number_of_intervals(self, number_of_intervals):
        """
        Sets the number_of_intervals of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :param number_of_intervals: The number_of_intervals of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :type: int
        """
        
        self._number_of_intervals = number_of_intervals

    @property
    def metrics(self):
        """
        Gets the metrics of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :return: The metrics of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :rtype: list[WfmIntradayDataUpdateTopicIntradayMetric]
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """
        Sets the metrics of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :param metrics: The metrics of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :type: list[WfmIntradayDataUpdateTopicIntradayMetric]
        """
        
        self._metrics = metrics

    @property
    def queue_ids(self):
        """
        Gets the queue_ids of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :return: The queue_ids of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :rtype: list[str]
        """
        return self._queue_ids

    @queue_ids.setter
    def queue_ids(self, queue_ids):
        """
        Sets the queue_ids of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :param queue_ids: The queue_ids of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :type: list[str]
        """
        
        self._queue_ids = queue_ids

    @property
    def intraday_data_groupings(self):
        """
        Gets the intraday_data_groupings of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :return: The intraday_data_groupings of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :rtype: list[WfmIntradayDataUpdateTopicIntradayDataGroup]
        """
        return self._intraday_data_groupings

    @intraday_data_groupings.setter
    def intraday_data_groupings(self, intraday_data_groupings):
        """
        Sets the intraday_data_groupings of this WfmIntradayDataUpdateTopicIntradayDataUpdate.


        :param intraday_data_groupings: The intraday_data_groupings of this WfmIntradayDataUpdateTopicIntradayDataUpdate.
        :type: list[WfmIntradayDataUpdateTopicIntradayDataGroup]
        """
        
        self._intraday_data_groupings = intraday_data_groupings

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'week_date': 'str',
            'creation_method': 'str',
            'description': 'str',
            'legacy': 'bool',
            'reference_start_date': 'datetime',
            'source_days': 'list[WfmBuShortTermForecastCopyCompleteTopicForecastSourceDayPointer]',
            'modifications': 'list[WfmBuShortTermForecastCopyCompleteTopicBuForecastModification]',
            'time_zone': 'str',
            'planning_groups_version': 'int',
            'week_count': 'int',
            'metadata': 'WfmBuShortTermForecastCopyCompleteTopicWfmVersionedEntityMetadata',
            'can_use_for_scheduling': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'week_date': 'weekDate',
            'creation_method': 'creationMethod',
            'description': 'description',
            'legacy': 'legacy',
            'reference_start_date': 'referenceStartDate',
            'source_days': 'sourceDays',
            'modifications': 'modifications',
            'time_zone': 'timeZone',
            'planning_groups_version': 'planningGroupsVersion',
            'week_count': 'weekCount',
            'metadata': 'metadata',
            'can_use_for_scheduling': 'canUseForScheduling'
        }

        self._id = None
        self._week_date = None
        self._creation_method = None
        self._description = None
        self._legacy = None
        self._reference_start_date = None
        self._source_days = None
        self._modifications = None
        self._time_zone = None
        self._planning_groups_version = None
        self._week_count = None
        self._metadata = None
        self._can_use_for_scheduling = None

    @property
    def id(self):
        """
        Gets the id of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :return: The id of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :param id: The id of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :type: str
        """
        
        self._id = id

    @property
    def week_date(self):
        """
        Gets the week_date of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :return: The week_date of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :rtype: str
        """
        return self._week_date

    @week_date.setter
    def week_date(self, week_date):
        """
        Sets the week_date of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :param week_date: The week_date of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :type: str
        """
        
        self._week_date = week_date

    @property
    def creation_method(self):
        """
        Gets the creation_method of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :return: The creation_method of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :rtype: str
        """
        return self._creation_method

    @creation_method.setter
    def creation_method(self, creation_method):
        """
        Sets the creation_method of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :param creation_method: The creation_method of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :type: str
        """
        allowed_values = ["Import", "ImportedHistoricalWeightedAverage", "HistoricalWeightedAverage", "Advanced"]
        if creation_method.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for creation_method -> " + creation_method)
            self._creation_method = "outdated_sdk_version"
        else:
            self._creation_method = creation_method

    @property
    def description(self):
        """
        Gets the description of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :return: The description of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :param description: The description of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :type: str
        """
        
        self._description = description

    @property
    def legacy(self):
        """
        Gets the legacy of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :return: The legacy of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :rtype: bool
        """
        return self._legacy

    @legacy.setter
    def legacy(self, legacy):
        """
        Sets the legacy of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :param legacy: The legacy of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :type: bool
        """
        
        self._legacy = legacy

    @property
    def reference_start_date(self):
        """
        Gets the reference_start_date of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :return: The reference_start_date of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :rtype: datetime
        """
        return self._reference_start_date

    @reference_start_date.setter
    def reference_start_date(self, reference_start_date):
        """
        Sets the reference_start_date of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :param reference_start_date: The reference_start_date of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :type: datetime
        """
        
        self._reference_start_date = reference_start_date

    @property
    def source_days(self):
        """
        Gets the source_days of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :return: The source_days of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :rtype: list[WfmBuShortTermForecastCopyCompleteTopicForecastSourceDayPointer]
        """
        return self._source_days

    @source_days.setter
    def source_days(self, source_days):
        """
        Sets the source_days of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :param source_days: The source_days of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :type: list[WfmBuShortTermForecastCopyCompleteTopicForecastSourceDayPointer]
        """
        
        self._source_days = source_days

    @property
    def modifications(self):
        """
        Gets the modifications of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :return: The modifications of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :rtype: list[WfmBuShortTermForecastCopyCompleteTopicBuForecastModification]
        """
        return self._modifications

    @modifications.setter
    def modifications(self, modifications):
        """
        Sets the modifications of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :param modifications: The modifications of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :type: list[WfmBuShortTermForecastCopyCompleteTopicBuForecastModification]
        """
        
        self._modifications = modifications

    @property
    def time_zone(self):
        """
        Gets the time_zone of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :return: The time_zone of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :param time_zone: The time_zone of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :type: str
        """
        
        self._time_zone = time_zone

    @property
    def planning_groups_version(self):
        """
        Gets the planning_groups_version of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :return: The planning_groups_version of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :rtype: int
        """
        return self._planning_groups_version

    @planning_groups_version.setter
    def planning_groups_version(self, planning_groups_version):
        """
        Sets the planning_groups_version of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :param planning_groups_version: The planning_groups_version of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :type: int
        """
        
        self._planning_groups_version = planning_groups_version

    @property
    def week_count(self):
        """
        Gets the week_count of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :return: The week_count of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :rtype: int
        """
        return self._week_count

    @week_count.setter
    def week_count(self, week_count):
        """
        Sets the week_count of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :param week_count: The week_count of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :type: int
        """
        
        self._week_count = week_count

    @property
    def metadata(self):
        """
        Gets the metadata of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :return: The metadata of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :rtype: WfmBuShortTermForecastCopyCompleteTopicWfmVersionedEntityMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :param metadata: The metadata of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :type: WfmBuShortTermForecastCopyCompleteTopicWfmVersionedEntityMetadata
        """
        
        self._metadata = metadata

    @property
    def can_use_for_scheduling(self):
        """
        Gets the can_use_for_scheduling of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :return: The can_use_for_scheduling of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :rtype: bool
        """
        return self._can_use_for_scheduling

    @can_use_for_scheduling.setter
    def can_use_for_scheduling(self, can_use_for_scheduling):
        """
        Sets the can_use_for_scheduling of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.


        :param can_use_for_scheduling: The can_use_for_scheduling of this WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast.
        :type: bool
        """
        
        self._can_use_for_scheduling = can_use_for_scheduling

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class HistoryListing(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        HistoryListing - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'complete': 'bool',
            'user': 'User',
            'client': 'DomainEntityRef',
            'error_message': 'str',
            'error_code': 'str',
            'error_details': 'list[Detail]',
            'error_message_params': 'dict(str, str)',
            'action_name': 'str',
            'action_status': 'str',
            'name': 'str',
            'description': 'str',
            'system': 'bool',
            'started': 'datetime',
            'completed': 'datetime',
            'entities': 'list[HistoryEntry]',
            'total': 'int',
            'page_number': 'int',
            'page_size': 'int',
            'page_count': 'int'
        }

        self.attribute_map = {
            'id': 'id',
            'complete': 'complete',
            'user': 'user',
            'client': 'client',
            'error_message': 'errorMessage',
            'error_code': 'errorCode',
            'error_details': 'errorDetails',
            'error_message_params': 'errorMessageParams',
            'action_name': 'actionName',
            'action_status': 'actionStatus',
            'name': 'name',
            'description': 'description',
            'system': 'system',
            'started': 'started',
            'completed': 'completed',
            'entities': 'entities',
            'total': 'total',
            'page_number': 'pageNumber',
            'page_size': 'pageSize',
            'page_count': 'pageCount'
        }

        self._id = None
        self._complete = None
        self._user = None
        self._client = None
        self._error_message = None
        self._error_code = None
        self._error_details = None
        self._error_message_params = None
        self._action_name = None
        self._action_status = None
        self._name = None
        self._description = None
        self._system = None
        self._started = None
        self._completed = None
        self._entities = None
        self._total = None
        self._page_number = None
        self._page_size = None
        self._page_count = None

    @property
    def id(self):
        """
        Gets the id of this HistoryListing.


        :return: The id of this HistoryListing.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this HistoryListing.


        :param id: The id of this HistoryListing.
        :type: str
        """
        
        self._id = id

    @property
    def complete(self):
        """
        Gets the complete of this HistoryListing.


        :return: The complete of this HistoryListing.
        :rtype: bool
        """
        return self._complete

    @complete.setter
    def complete(self, complete):
        """
        Sets the complete of this HistoryListing.


        :param complete: The complete of this HistoryListing.
        :type: bool
        """
        
        self._complete = complete

    @property
    def user(self):
        """
        Gets the user of this HistoryListing.


        :return: The user of this HistoryListing.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this HistoryListing.


        :param user: The user of this HistoryListing.
        :type: User
        """
        
        self._user = user

    @property
    def client(self):
        """
        Gets the client of this HistoryListing.


        :return: The client of this HistoryListing.
        :rtype: DomainEntityRef
        """
        return self._client

    @client.setter
    def client(self, client):
        """
        Sets the client of this HistoryListing.


        :param client: The client of this HistoryListing.
        :type: DomainEntityRef
        """
        
        self._client = client

    @property
    def error_message(self):
        """
        Gets the error_message of this HistoryListing.


        :return: The error_message of this HistoryListing.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this HistoryListing.


        :param error_message: The error_message of this HistoryListing.
        :type: str
        """
        
        self._error_message = error_message

    @property
    def error_code(self):
        """
        Gets the error_code of this HistoryListing.


        :return: The error_code of this HistoryListing.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """
        Sets the error_code of this HistoryListing.


        :param error_code: The error_code of this HistoryListing.
        :type: str
        """
        
        self._error_code = error_code

    @property
    def error_details(self):
        """
        Gets the error_details of this HistoryListing.


        :return: The error_details of this HistoryListing.
        :rtype: list[Detail]
        """
        return self._error_details

    @error_details.setter
    def error_details(self, error_details):
        """
        Sets the error_details of this HistoryListing.


        :param error_details: The error_details of this HistoryListing.
        :type: list[Detail]
        """
        
        self._error_details = error_details

    @property
    def error_message_params(self):
        """
        Gets the error_message_params of this HistoryListing.


        :return: The error_message_params of this HistoryListing.
        :rtype: dict(str, str)
        """
        return self._error_message_params

    @error_message_params.setter
    def error_message_params(self, error_message_params):
        """
        Sets the error_message_params of this HistoryListing.


        :param error_message_params: The error_message_params of this HistoryListing.
        :type: dict(str, str)
        """
        
        self._error_message_params = error_message_params

    @property
    def action_name(self):
        """
        Gets the action_name of this HistoryListing.
        Action name

        :return: The action_name of this HistoryListing.
        :rtype: str
        """
        return self._action_name

    @action_name.setter
    def action_name(self, action_name):
        """
        Sets the action_name of this HistoryListing.
        Action name

        :param action_name: The action_name of this HistoryListing.
        :type: str
        """
        allowed_values = ["CREATE", "CHECKIN", "DEBUG", "DELETE", "HISTORY", "PUBLISH", "STATE_CHANGE", "UPDATE", "VALIDATE"]
        if action_name.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for action_name -> " + action_name)
            self._action_name = "outdated_sdk_version"
        else:
            self._action_name = action_name

    @property
    def action_status(self):
        """
        Gets the action_status of this HistoryListing.
        Action status

        :return: The action_status of this HistoryListing.
        :rtype: str
        """
        return self._action_status

    @action_status.setter
    def action_status(self, action_status):
        """
        Sets the action_status of this HistoryListing.
        Action status

        :param action_status: The action_status of this HistoryListing.
        :type: str
        """
        allowed_values = ["LOCKED", "UNLOCKED", "STARTED", "PENDING_GENERATION", "PENDING_BACKEND_NOTIFICATION", "SUCCESS", "FAILURE"]
        if action_status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for action_status -> " + action_status)
            self._action_status = "outdated_sdk_version"
        else:
            self._action_status = action_status

    @property
    def name(self):
        """
        Gets the name of this HistoryListing.


        :return: The name of this HistoryListing.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this HistoryListing.


        :param name: The name of this HistoryListing.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this HistoryListing.


        :return: The description of this HistoryListing.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this HistoryListing.


        :param description: The description of this HistoryListing.
        :type: str
        """
        
        self._description = description

    @property
    def system(self):
        """
        Gets the system of this HistoryListing.


        :return: The system of this HistoryListing.
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """
        Sets the system of this HistoryListing.


        :param system: The system of this HistoryListing.
        :type: bool
        """
        
        self._system = system

    @property
    def started(self):
        """
        Gets the started of this HistoryListing.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The started of this HistoryListing.
        :rtype: datetime
        """
        return self._started

    @started.setter
    def started(self, started):
        """
        Sets the started of this HistoryListing.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param started: The started of this HistoryListing.
        :type: datetime
        """
        
        self._started = started

    @property
    def completed(self):
        """
        Gets the completed of this HistoryListing.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The completed of this HistoryListing.
        :rtype: datetime
        """
        return self._completed

    @completed.setter
    def completed(self, completed):
        """
        Sets the completed of this HistoryListing.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param completed: The completed of this HistoryListing.
        :type: datetime
        """
        
        self._completed = completed

    @property
    def entities(self):
        """
        Gets the entities of this HistoryListing.


        :return: The entities of this HistoryListing.
        :rtype: list[HistoryEntry]
        """
        return self._entities

    @entities.setter
    def entities(self, entities):
        """
        Sets the entities of this HistoryListing.


        :param entities: The entities of this HistoryListing.
        :type: list[HistoryEntry]
        """
        
        self._entities = entities

    @property
    def total(self):
        """
        Gets the total of this HistoryListing.


        :return: The total of this HistoryListing.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """
        Sets the total of this HistoryListing.


        :param total: The total of this HistoryListing.
        :type: int
        """
        
        self._total = total

    @property
    def page_number(self):
        """
        Gets the page_number of this HistoryListing.


        :return: The page_number of this HistoryListing.
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """
        Sets the page_number of this HistoryListing.


        :param page_number: The page_number of this HistoryListing.
        :type: int
        """
        
        self._page_number = page_number

    @property
    def page_size(self):
        """
        Gets the page_size of this HistoryListing.


        :return: The page_size of this HistoryListing.
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """
        Sets the page_size of this HistoryListing.


        :param page_size: The page_size of this HistoryListing.
        :type: int
        """
        
        self._page_size = page_size

    @property
    def page_count(self):
        """
        Gets the page_count of this HistoryListing.


        :return: The page_count of this HistoryListing.
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """
        Sets the page_count of this HistoryListing.


        :param page_count: The page_count of this HistoryListing.
        :type: int
        """
        
        self._page_count = page_count

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Metrics(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Metrics - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'order': 'int',
            'metric_definition_name': 'str',
            'metric_definition_id': 'str',
            'unit_type': 'str',
            'enabled': 'bool',
            'template_name': 'str',
            'max_points': 'int',
            'performance_profile_id': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'order': 'order',
            'metric_definition_name': 'metricDefinitionName',
            'metric_definition_id': 'metricDefinitionId',
            'unit_type': 'unitType',
            'enabled': 'enabled',
            'template_name': 'templateName',
            'max_points': 'maxPoints',
            'performance_profile_id': 'performanceProfileId',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._order = None
        self._metric_definition_name = None
        self._metric_definition_id = None
        self._unit_type = None
        self._enabled = None
        self._template_name = None
        self._max_points = None
        self._performance_profile_id = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Metrics.
        The globally unique identifier for the object.

        :return: The id of this Metrics.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Metrics.
        The globally unique identifier for the object.

        :param id: The id of this Metrics.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Metrics.


        :return: The name of this Metrics.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Metrics.


        :param name: The name of this Metrics.
        :type: str
        """
        
        self._name = name

    @property
    def order(self):
        """
        Gets the order of this Metrics.
        The order of metric within a performance profile

        :return: The order of this Metrics.
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """
        Sets the order of this Metrics.
        The order of metric within a performance profile

        :param order: The order of this Metrics.
        :type: int
        """
        
        self._order = order

    @property
    def metric_definition_name(self):
        """
        Gets the metric_definition_name of this Metrics.
        The name of associated metric definition

        :return: The metric_definition_name of this Metrics.
        :rtype: str
        """
        return self._metric_definition_name

    @metric_definition_name.setter
    def metric_definition_name(self, metric_definition_name):
        """
        Sets the metric_definition_name of this Metrics.
        The name of associated metric definition

        :param metric_definition_name: The metric_definition_name of this Metrics.
        :type: str
        """
        
        self._metric_definition_name = metric_definition_name

    @property
    def metric_definition_id(self):
        """
        Gets the metric_definition_id of this Metrics.
        The id of associated metric definition

        :return: The metric_definition_id of this Metrics.
        :rtype: str
        """
        return self._metric_definition_id

    @metric_definition_id.setter
    def metric_definition_id(self, metric_definition_id):
        """
        Sets the metric_definition_id of this Metrics.
        The id of associated metric definition

        :param metric_definition_id: The metric_definition_id of this Metrics.
        :type: str
        """
        
        self._metric_definition_id = metric_definition_id

    @property
    def unit_type(self):
        """
        Gets the unit_type of this Metrics.
        Corresponding unit type for this metric

        :return: The unit_type of this Metrics.
        :rtype: str
        """
        return self._unit_type

    @unit_type.setter
    def unit_type(self, unit_type):
        """
        Sets the unit_type of this Metrics.
        Corresponding unit type for this metric

        :param unit_type: The unit_type of this Metrics.
        :type: str
        """
        allowed_values = ["None", "Percent", "Seconds", "Number", "AttendanceStatus", "Unit"]
        if unit_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for unit_type -> " + unit_type)
            self._unit_type = "outdated_sdk_version"
        else:
            self._unit_type = unit_type

    @property
    def enabled(self):
        """
        Gets the enabled of this Metrics.
        A flag for whether this metric is enabled for a performance profile

        :return: The enabled of this Metrics.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this Metrics.
        A flag for whether this metric is enabled for a performance profile

        :param enabled: The enabled of this Metrics.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def template_name(self):
        """
        Gets the template_name of this Metrics.
        The name of associated objective template

        :return: The template_name of this Metrics.
        :rtype: str
        """
        return self._template_name

    @template_name.setter
    def template_name(self, template_name):
        """
        Sets the template_name of this Metrics.
        The name of associated objective template

        :param template_name: The template_name of this Metrics.
        :type: str
        """
        
        self._template_name = template_name

    @property
    def max_points(self):
        """
        Gets the max_points of this Metrics.
        Achievable maximum points for this metric

        :return: The max_points of this Metrics.
        :rtype: int
        """
        return self._max_points

    @max_points.setter
    def max_points(self, max_points):
        """
        Sets the max_points of this Metrics.
        Achievable maximum points for this metric

        :param max_points: The max_points of this Metrics.
        :type: int
        """
        
        self._max_points = max_points

    @property
    def performance_profile_id(self):
        """
        Gets the performance_profile_id of this Metrics.
        Performance profile id of this metric

        :return: The performance_profile_id of this Metrics.
        :rtype: str
        """
        return self._performance_profile_id

    @performance_profile_id.setter
    def performance_profile_id(self, performance_profile_id):
        """
        Sets the performance_profile_id of this Metrics.
        Performance profile id of this metric

        :param performance_profile_id: The performance_profile_id of this Metrics.
        :type: str
        """
        
        self._performance_profile_id = performance_profile_id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Metrics.
        The URI for this object

        :return: The self_uri of this Metrics.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Metrics.
        The URI for this object

        :param self_uri: The self_uri of this Metrics.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

